pub struct ShellMetaRule { /* private fields */ }Expand description
Rejects input containing shell metacharacters.
Default denied characters: ;, |, &, $, `, (, ), {, },
<, >, !, #, \, ', ", ~, \n, \r.
Rationale
These characters enable:
- Command chaining (
;,&&,||) - Piping (
|) - Subshell / command substitution (
$(),`) - Redirection (
<,>) - Backgrounding (
&) - Comment injection (
#) - Home directory expansion (
~)
Implementations
Sourceimpl ShellMetaRule
impl ShellMetaRule
Sourcepub fn with_denied(denied: Vec<char>) -> Self
pub fn with_denied(denied: Vec<char>) -> Self
Create a rule with a custom set of denied characters.
Sourcepub fn with_extra_denied(extra: &[char]) -> Self
pub fn with_extra_denied(extra: &[char]) -> Self
Create a rule with additional denied characters on top of defaults.